.. _phononic-examples-index:

phononic
========

.. toctree::
   :maxdepth: 2

   band_gaps.py <phononic-band_gaps>
   band_gaps_conf.py <phononic-band_gaps_conf>
   band_gaps_rigid.py <phononic-band_gaps_rigid>
